# JupyterLab Chinese (Simplified, China) Language Pack

[![Crowdin](https://badges.crowdin.net/jupyterlab/localized.svg)](https://crowdin.com/project/jupyterlab)

Chinese (Simplified, China) language pack for [JupyterLab](https://github.com/jupyterlab/jupyterlab).

## Install

### pip

```bash
pip install jupyterlab-language-pack-zh-CN
```

### conda

```bash
conda install jupyterlab-language-pack-zh-CN -c conda-forge
```

## Contributing

To contribute to this package please visit the [Crowdin site](https://crowdin.com/project/jupyterlab).
